# lambkid

lambkid is an advance lib abstract from some common use python lib. it aim to supply a more easily and more fewer code for python developer.
it will practise for life is short and I will choose python.

## install lambkid
refer to [install lambkid](docs/install.md)

## function of lambkid
* [sshclient](docs/sshclient.md)(>=0.0.6)
* [log](docs/log.md) (>==0.0.4)
